<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>osd::DisPlayModeApplet</name>
    <message>
        <source>Duplicate</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Extend</source>
        <translation>扩展</translation>
    </message>
    <message>
        <source>Only on %1</source>
        <translation>仅 %1</translation>
    </message>
</context>
</TS>